@@ -9,4 +9,9 @@ setGeneric( "has", function( object, name, ... ){
 		return(.Call( "Message__has_field", object@pointer, name, PACKAGE = "RProtoBuf" ))
 	}
 }
+._has_enum_name <- function( object, name, ...){
+  return(.Call( "has_enum_name", object@pointer, name, package = "RProtoBuf"))
+}
+
 setMethod( "has", "Message", ._has_message )
+setMethod( "has", "EnumDescriptor", ._has_enum_name)
